import re
import requests
from typing import Optional

from fastapi import HTTPException

from src.base import config
from src.utils.logger import logger

gitee_http_partten = r'https://gitee.com/(.*)/(.*)'
gitee_ssh_partten = r'git@gitee.com:(.*)/(.*).git'


def check_gitee_address(address: str) -> bool:
    try:
        if address.startswith('https'):
            partten = gitee_http_partten
        else:
            partten = gitee_ssh_partten
        matchObj = re.match(partten, address, re.M | re.I)
        if matchObj:
            return True
        else:
            return False
    except:
        return False


def gitee_auth(token: str) -> bool:
    pass


def get_gitee_address_with_token(http_address: str, token: str) -> str:
    try:
        if not http_address.startswith('http'):
            raise Exception('http address is error')
        if token == "":
            raise Exception('token is empty')
        owner_name = http_address[8:].split("/")[1]
        return http_address[:8] + owner_name + ":" + token + '@' + http_address[8:]
    except Exception as e:
        print(e)

def fetch_gitee_pull_request(token: str, owner: str, repo: str, state: str = None):
    """
    获取指定仓库的PR数据

    Attributes：
        token 用户授权码
        owner 仓库拥有者
        repo 仓库名称
        state 可选，PR的状态。
    """
    # 根据state决定request的地址
    if state:
        url = f'https://gitee.com/api/v5/repos/{owner}/{repo}/pulls?state={state}'
    else:
        url = f'https://gitee.com/api/v5/repos/{owner}/{repo}/pulls'
    # 请求头的内容
    headers = {
        'Authorization': f'token {token}'
    }
    response = requests.get(url, headers=headers)
    pull_requests = response.json()
    data = []
    for pull_request in pull_requests:
        data_item = {
            'pull_request_id': pull_request['id'],
            'project': repo,
            'title': pull_request['title'],
            'type': 'Gitee',
            'address': pull_request['html_url'],
            'author': pull_request['user']['login'],
            'email': None,
            'target_branch': pull_request['base']['ref'],
            'latest_commit': pull_request['head']['sha'],
            'inline': pull_request['base']['repo']['internal'],
        }
        data.append(data_item)
    return data
def create_pull_request(owner: str, repo: str, title: str, head: str, base: str):
    """
    创建一个合并请求

    Attributes:
        owner 仓库拥有者
        repo 仓库名称
        title PR的标题
        head PR提交的源分支
        base PR的目标分支
    """
    pass

def fetch_gitee_issues(owner: str, repo: str):
    url = f'https://gitee.com/api/v5/repos/{owner}/{repo}/issues'
    response = requests.get(url)
    issues = response.json()
    issue_list = []
    for issue in issues:
        state = 1
        if issue['state'] == 'progressing':
            state = 2
        elif issue['state'] == 'closed':
            state = 5
        elif issue['state'] == 'rejected':
            state = 6
        issue_item = {
            'status_id': state,
            'priority_id': 1,
            'subject': issue['title'],
            'description': issue['body']
        }
        issue_list.append(issue_item)
    return issue_list