import { useEffect } from 'react';
import { Modal, Button, Spin } from 'antd';
import { getJobLog } from '@/services/Jobs';
import useRequest from '@/utils/useRequest';
import moment from 'moment';

interface Props {
  visible: boolean;
  onCancel: () => void;
  name?: string;
  id?: number
}

export default (props: Props) => {
  const { visible, onCancel, name, id } = props;
  const { run: fetchJobLog, loading, data: logsData } = useRequest(getJobLog);

  useEffect(() => {
    fetchJobLog({ name, id });
  }, [])

  return (
    <Modal
      title="查看日志"
      visible={visible}
      onCancel={onCancel}
      width={800}
      footer={<Button onClick={onCancel} >关闭</Button>}
      bodyStyle={{ overflow: 'auto', maxHeight: 600 }}
    >
      <Spin spinning={loading} >
        {
          logsData?.data?.list?.map((item: API.Log, index: number) => (
            <>
              <div>{moment(item.create_time).format('YYYY-MM-DD HH:mm:ss')}【{item.log_type}】{item.log}</div>
              {index === logsData?.data?.list?.length ? <br/> : null }
            </>
          ))
        }
      </Spin>
    </Modal>
  );
};

export default (props) => {
  // ...解构 props 和定义其他状态...

  const [error, setError] = useState(null); // 添加错误状态

  useEffect(() => {
    fetchJobLog({ name, id })
      .then(response => {
        // 处理成功的情况，例如设置数据状态等
      })
      .catch(error => {
        setError(error); // 捕获错误并设置错误状态
        message.error('获取日志失败，请稍后重试或联系管理员。'); // 显示错误提示信息
      });
  }, [name, id]); // 依赖数组中添加 name 和 id

  // ...其他代码保持不变...

  return (
    <Modal
    // ...其他属性保持不变...
    >
      <Spin spinning={loading}>
        {error ? (
          // 如果存在错误，展示错误信息
          <div style={{ padding: '20px', textAlign: 'center' }}>
            <b>错误信息：</b> {error.message || '未知错误'}
          </div>
        ) : (
          // 正常渲染日志列表
          logsData?.data?.list?.map((item, index) => (
            // ...渲染日志项...
          ))
        )}
      </Spin>
    </Modal>
  );
};
